@@ -18,8 +18,8 @@ use Errorlog::TeeOutput;
 # Can't locate object method "BINMODE" via package "Errorlog::TeeOutput::NewTee" at /home/anton/bin/keymaster line 10.
 #
 
-my $version = '$Id: Errorlog.pm 40273 2013-09-23 10:05:25Z anton $ ';
-our $VERSION = "1.32";
+my $version = '$Id: Errorlog.pm 40359M 2013-10-04 11:32:20Z (local) $ ';
+our $VERSION = "1.34";
 #global variable, needed for TeeOutput
 our $SELF;
 
@@ -63,8 +63,7 @@ sub new {
 	my $self = bless (new Baseobject(@_),$pkg);
 	$self->{tstart} = [gettimeofday];
 	$self->{tstored} = $self->{tstart};
-
-	$self->field('name','Log');
+	$self->field('name', 'Log');
 
 	my $fh;
 	my $logfile = $self->makelogfilename();
@@ -97,12 +96,13 @@ sub new {
 			'output' => [qw (stderr logbuffer)],
 			'printinfo' => 1,
 			'sysloglevel' => 'info',
-			'syslogmaxbuf' => 512+255, # just guessing, 1024 is too big, things get truncated
+			'syslogmaxbuf' => 512 + 255, # just guessing, 1024 is too big, things get truncated
 			'hirestimer' => 0,
 			'user' => $user,
 			'version' => $VERSION,
 			'autoconfess' => 1,
 			'skipEND' => '',
+			'noDebug2Syslog' => 1,
 		}
 		);
 
@@ -125,6 +125,28 @@ sub new {
 
 	my @params = ();
 	my %params;
+	my $syslogSuppressed = '';
+
+	if ($self->{outputmodes}->{syslog}) {
+		if (openlog($0, 'cons,pid',$self->{fields}->{facility}) ) {
+			$params{'syslog'} = 1; #1 is dummy value
+		} else {
+			$self->error("Could not open syslog");
+		}
+	}
+
+	if ($self->{fields}->{noDebug2Syslog}) {
+		if ($Baseobject::verbosity >= 2) {
+			if ($self->{outputmodes}->{syslog}) {
+				$syslogSuppressed = "Warning ($0): Debug output is not allowed in syslog but redirected to: \"$logdir/$logfile\"\n";
+				warn $syslogSuppressed;
+				$self->{outputmodes}->{logfile} = 1;
+				syslog('alert', $syslogSuppressed);
+				$self->{outputmodes}->{syslog} = 0;
+				closelog();
+			}
+		}
+	}
 
 	if ($self->{outputmodes}->{logfile}) {
 		$logdir = $self->field('logdir');
@@ -157,14 +179,6 @@ sub new {
 		push (@params, ">>$logfile");
 	}
 
-	if ($self->{outputmodes}->{syslog}) {
-		if (openlog($0, 'cons,pid',$self->{fields}->{facility}) ) {
-			$params{'syslog'} = 1; #1 is dummy value
-		} else {
-			$self->error("Could not open syslog");
-		}
-	}
-
 	#do this for now, must think about it some more
 	$self->{outputmodes}->{logbuffer} = 1 if $self->{fields}->{mailonfailure};
 
@@ -201,8 +215,8 @@ sub field {
 	if ($_[1]) {
 		#sysloglevel
 		if ($_[0]eq 'sysloglevel') {
-			my @sysloglevels=qw (emerg alert crit err warning notice info debug);
-			my $sysloglevel=$_[1];
+			my @sysloglevels = qw (emerg alert crit err warning notice info debug);
+			my $sysloglevel = $_[1];
 
 			unless (grep ( /^$sysloglevel$/, @sysloglevels)) {
 				$self->error("invalid sysloglevel: \"$sysloglevel\", accepted levels are: @sysloglevels" );
@@ -213,8 +227,7 @@ sub field {
 			map {$self->{outputmodes}->{$_} = 0} @outputmodes;
 
 			foreach my $mode (@{$_[1]}) {
-				if (grep (/^$mode$/, @outputmodes))
-				{
+				if (grep (/^$mode$/, @outputmodes)) {
 					$self->{outputmodes}->{$mode} = 1;
 				} else {
 					#in case of error leave stderr intact!
@@ -319,16 +332,15 @@ sub teecallback {
 }
 
 
-sub hiResTime
-{
-	my $self=shift;
-	my $tprev=$self->{tstored};
+sub hiResTime {
+	my $self = shift;
+	my $tprev = $self->{tstored};
 	$self->{tstored} = [gettimeofday];
 
-	my $tdif=tv_interval ($tprev, $self->{tstored});
-	my $ttotal=tv_interval ($self->{tstart}, $self->{tstored});
-	my $slow='';
-	$slow=" TIME POOL" if ($tdif >= $self->{fields}->{hirestimer});
+	my $tdif = tv_interval ($tprev, $self->{tstored});
+	my $ttotal = tv_interval ($self->{tstart}, $self->{tstored});
+	my $slow = '';
+	$slow = " TIME POOL" if ($tdif >= $self->{fields}->{hirestimer});
 
 	return "dt: $tdif tt: ${ttotal}$slow - ";
 }
@@ -491,7 +503,7 @@ sub overrule {
 		foreach $basepart ('defaults', $self->basefilename(),'overrule') {
 			$configfile = "$configdir/${basepart}_errorlog.cf";
 			next unless -r $configfile;
-			carp "Found configfile: $configfile" if $Baseobject::verbosity >=2 ;
+			carp "Using additional configfile: $configfile"; #if $Baseobject::verbosity >=2 ;
 			unless (open ($fh,$configfile)) {
 				carp "Found but could not open configfile: $configfile, $!";
 				return;
@@ -505,16 +517,16 @@ sub overrule {
 
 				my ($name, $split, $value) = split /\s*([=\|])\s*/;
 				my @values = split (/,/, $value);
-#      carp $self->inspect($name, $value, $split,\@values);
+#				carp $self->inspect($name, $value, $split,\@values);
 
 				if ($name eq 'verbosity') {
+					carp "Configfile: $configfile, verbosity: $value";
 					verbosity($value);
 					freezeverbosity(1) if $split eq '=';
 					next;
 				}
 
 				my $ref = ref($self->field($name));
-
 				#the target expects an array
 				if ($ref eq 'ARRAY') {
 					if ($split eq '=') {
@@ -548,6 +560,25 @@ sub uniquelist {
 	return [keys (%hash)];
 }
 
+
+# overloaden van Baseobject::debug
+sub debug {
+	my $self = shift;
+	if (verbosity() >= 2) {
+		my ($package, $file, $line) = caller;
+		foreach my $el (@_) {
+			my $location = '';
+			$location = " at $file line $line" unless $el =~ /\n$/;
+			my $savedLogLevel = $self->{fields}->{sysloglevel};
+			$self->{fields}->{sysloglevel} = 'debug';
+			carp " $el$location";
+			$self->{fields}->{sysloglevel} = $savedLogLevel;
+		}
+	}
+}
+
+
+
 42;
 
 
